@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
-# $Revision: #13 $$Date: 2004/08/20 $$Author: ws150726 $
+# $Revision: 1.14 $$Date: 2005-03-01 17:59:56 -0500 (Tue, 01 Mar 2005) $$Author: wsnyder $
 # DESCRIPTION: Perl ExtUtils: Type 'make test' to test this package
 #
-# Copyright 2001-2004 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2005 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 
@@ -36,7 +36,7 @@ if (! -x "$dir/ex_main"
     run_system ("cd $dir && ./ex_main");
     ok(1);
     ok(-r "$dir/sim_sc.vcd");
-    ok(-r "$dir/sim_sp.dump");
+    ok(-r "$dir/sim_sp.vcd");
     run_system ("cd $dir && ../vcoverage -y ../");
     ok(-r "$dir/logs/coverage_source/ExModSub.sp");
 }
